@@ -1,6 +1,7 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from ...mappings import Types
 from graphene import Field, InputObjectType, String
+from graphql import Undefined
 
 
 class NestedItemUpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -19,11 +20,13 @@ class NestedItemUpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                         Types.PK_INPUT_TYPE, model_class=model_class
                     ),
                     required=pk_required,
+                    default_value=Undefined,
                 ),
-                "tag": Field(String),
+                "tag": Field(String, default_value=Undefined),
                 "data": Field(
                     registry.lambda_from_registry(model_class, Types.UPDATE_INPUT_TYPE),
                     required=True,
+                    default_value=Undefined,
                 ),
             },
         )
